@@ -21,7 +21,7 @@ use Exporter::Shiny qw(
     default_profile
 );
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our %EXPORT_TAGS = (
     ini  => [qw( read_file read_string read_handle )],
     aws  => [qw( config_file default_profile credentials_file )],
@@ -78,7 +78,7 @@ sub read_file {
 sub read_string {
     croak 'String is missing' unless @_ >= 1;
     croak 'Argument was not a string' if is_ref $_[0];
-    _read( [ split /\n/, shift ], @_ );
+    _read( [ split /\n/, shift // '' ], @_ );
 }
 
 sub read_handle {
